LockedDownTraits
================

.. currentmodule:: wwt_data_formats

.. autoclass:: LockedDownTraits
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~LockedDownTraits.cross_validation_lock
      ~LockedDownTraits.rmeta

   .. rubric:: Methods Summary

   .. autosummary::

      ~LockedDownTraits.add_traits
      ~LockedDownTraits.class_own_trait_events
      ~LockedDownTraits.class_own_traits
      ~LockedDownTraits.class_trait_names
      ~LockedDownTraits.class_traits
      ~LockedDownTraits.has_trait
      ~LockedDownTraits.hold_trait_notifications
      ~LockedDownTraits.notify_change
      ~LockedDownTraits.observe
      ~LockedDownTraits.on_trait_change
      ~LockedDownTraits.set_trait
      ~LockedDownTraits.setup_instance
      ~LockedDownTraits.trait_defaults
      ~LockedDownTraits.trait_events
      ~LockedDownTraits.trait_has_value
      ~LockedDownTraits.trait_metadata
      ~LockedDownTraits.trait_names
      ~LockedDownTraits.trait_values
      ~LockedDownTraits.traits
      ~LockedDownTraits.unobserve
      ~LockedDownTraits.unobserve_all

   .. rubric:: Attributes Documentation

   .. autoattribute:: cross_validation_lock
   .. autoattribute:: rmeta

   .. rubric:: Methods Documentation

   .. automethod:: add_traits
   .. automethod:: class_own_trait_events
   .. automethod:: class_own_traits
   .. automethod:: class_trait_names
   .. automethod:: class_traits
   .. automethod:: has_trait
   .. automethod:: hold_trait_notifications
   .. automethod:: notify_change
   .. automethod:: observe
   .. automethod:: on_trait_change
   .. automethod:: set_trait
   .. automethod:: setup_instance
   .. automethod:: trait_defaults
   .. automethod:: trait_events
   .. automethod:: trait_has_value
   .. automethod:: trait_metadata
   .. automethod:: trait_names
   .. automethod:: trait_values
   .. automethod:: traits
   .. automethod:: unobserve
   .. automethod:: unobserve_all
